### Is this issue a "Bug Report :warning::bug:"  or a "Feature Request 
:star:" ?

- [ ] Please check for similar existing issues before submitting.
- [ ] Please fill out the appropriate template below and remove the unused 
template.
- [ ] Please tag your issue with either BUG or ENHANCEMENT tag
- [ ] Please remove this section before submitting.


## Bug Report Details :warning::bug: 
### Description

[Description of the bug]  
[Include images where appropriate]

### Steps to Reproduce

- [ ] Is the bug reproducible?

1. [First Step]
2. [Second Step]
3. [Include images]
4. [and so on...]

**Expected behavior:** [What you expected to happen]

**Actual behavior:** [What actually happened]


## Feature Request Details :star:
### Description

[Description of the feature]  
[Include images where appropriate]

### Links to feature design doc, conversations, mockups, etc.
[Provide links or documents here for context.]

### Stakeholders
[Please reference the stakeholders for this feature]

### Functional Requirements
[What does the feature need to do?]  
[Describe system behaviors using [ubiquitous 
language](http://ddd.fed.wiki.org/view/ubiquitous-language) and [intention 
revealing 
interfaces](http://ddd.fed.wiki.org/view/intention-revealing-interfaces).]  

### Non-functional Requirements
[What constraints exist for this feature?]  
[All constraints must be quantifiable.]

### Acceptance Criteria
[What needs to happen functionally for this work to pass review?]  
[Usually a combination of FRs and NFRs as test cases written in plain 
text.]
